irl\_benchmark.irl package
==========================

Subpackages
-----------

.. toctree::

    irl_benchmark.irl.algorithms
    irl_benchmark.irl.collect
    irl_benchmark.irl.feature
    irl_benchmark.irl.reward

Module contents
---------------

.. automodule:: irl_benchmark.irl
    :members:
    :undoc-members:
    :show-inheritance:
